@@ -97,6 +97,17 @@ options, args = parser.parse_args()
 ######################################################################
 # load/install setuptools
 
+def _cleanup_old_zc_buildout_modules():
+    # installing setuptools imported the site module, which added all the stuff in site-packages to sys.path,
+    # even though in the case Python was executed -S.
+    # we want to remove all traces for this
+    for item in sys.path:
+        if 'zc' in item:
+            sys.path.remove(item)
+    for module in sys.modules.keys():
+        if 'zc' in module:
+            del sys.modules[module]
+
 to_reload = False
 import glob
 import re
@@ -213,6 +224,7 @@ if subprocess.call(cmd, env=dict(os.environ, PYTHONPATH=setuptools_path)) != 0:
 # installing setuptools imported site.py, which added zc.buildout to the WorkingSet if it was previously installed
 # this may raise a VerionConflict here; we just need to resolve the location of the buildout we just installed
 # so we clear the WorkingSet
+_cleanup_old_zc_buildout_modules()
 ws.by_key = {}
 ws.add_entry(tmpeggs)
 ws.require(requirement)
